# Changelog

## 0.1.0-alpha.1 (2025-05-23)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/slashfi/slash-sdk-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([defc219](https://github.com/slashfi/slash-sdk-python/commit/defc2195b9414cca95fa00887cc17ce384200534))


### Chores

* update SDK settings ([f00a22b](https://github.com/slashfi/slash-sdk-python/commit/f00a22bc7b33f7c323155e243cf3a8731ec81e77))
* update SDK settings ([f4f4a22](https://github.com/slashfi/slash-sdk-python/commit/f4f4a2231d99b105cb4eb8117ee0589bf5290b01))
* update SDK settings ([9041231](https://github.com/slashfi/slash-sdk-python/commit/90412312699787194863b1a20366617e2df59466))
